# Auto-generated __init__.py
from . import auth_pb2, auth_pb2_grpc, errors_pb2, errors_pb2_grpc, resources_pb2, resources_pb2_grpc, types_pb2, types_pb2_grpc

__all__ = ["auth_pb2", "auth_pb2_grpc", "errors_pb2", "errors_pb2_grpc", "resources_pb2", "resources_pb2_grpc", "types_pb2", "types_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/expr/v1beta1/expr.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/expr/v1beta1/expr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import source_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_source__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/api/expr/v1beta1/expr.proto\x12\x17google.api.expr.v1beta1\x1a$google/api/expr/v1beta1/source.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xac\x01\n\nParsedExpr\x12\x31\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x04\x65xpr\x12\x44\n\x0bsource_info\x18\x03 \x01(\x0b\x32#.google.api.expr.v1beta1.SourceInfoR\nsourceInfo\x12%\n\x0esyntax_version\x18\x04 \x01(\tR\rsyntaxVersion\"\xbd\x0c\n\x04\x45xpr\x12\x0e\n\x02id\x18\x02 \x01(\x05R\x02id\x12\x45\n\x0cliteral_expr\x18\x03 \x01(\x0b\x32 .google.api.expr.v1beta1.LiteralH\x00R\x0bliteralExpr\x12\x44\n\nident_expr\x18\x04 \x01(\x0b\x32#.google.api.expr.v1beta1.Expr.IdentH\x00R\tidentExpr\x12G\n\x0bselect_expr\x18\x05 \x01(\x0b\x32$.google.api.expr.v1beta1.Expr.SelectH\x00R\nselectExpr\x12\x41\n\tcall_expr\x18\x06 \x01(\x0b\x32\".google.api.expr.v1beta1.Expr.CallH\x00R\x08\x63\x61llExpr\x12G\n\tlist_expr\x18\x07 \x01(\x0b\x32(.google.api.expr.v1beta1.Expr.CreateListH\x00R\x08listExpr\x12M\n\x0bstruct_expr\x18\x08 \x01(\x0b\x32*.google.api.expr.v1beta1.Expr.CreateStructH\x00R\nstructExpr\x12\\\n\x12\x63omprehension_expr\x18\t \x01(\x0b\x32+.google.api.expr.v1beta1.Expr.ComprehensionH\x00R\x11\x63omprehensionExpr\x1a\x1b\n\x05Ident\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1at\n\x06Select\x12\x37\n\x07operand\x18\x01 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x07operand\x12\x14\n\x05\x66ield\x18\x02 \x01(\tR\x05\x66ield\x12\x1b\n\ttest_only\x18\x03 \x01(\x08R\x08testOnly\x1a\x8c\x01\n\x04\x43\x61ll\x12\x35\n\x06target\x18\x01 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x06target\x12\x1a\n\x08\x66unction\x18\x02 \x01(\tR\x08\x66unction\x12\x31\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x04\x61rgs\x1aG\n\nCreateList\x12\x39\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x08\x65lements\x1a\xa2\x02\n\x0c\x43reateStruct\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12J\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x30.google.api.expr.v1beta1.Expr.CreateStruct.EntryR\x07\x65ntries\x1a\xb1\x01\n\x05\x45ntry\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02id\x12\x1d\n\tfield_key\x18\x02 \x01(\tH\x00R\x08\x66ieldKey\x12\x38\n\x07map_key\x18\x03 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprH\x00R\x06mapKey\x12\x33\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x05valueB\n\n\x08key_kind\x1a\xf8\x02\n\rComprehension\x12\x19\n\x08iter_var\x18\x01 \x01(\tR\x07iterVar\x12<\n\niter_range\x18\x02 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\titerRange\x12\x19\n\x08\x61\x63\x63u_var\x18\x03 \x01(\tR\x07\x61\x63\x63uVar\x12:\n\taccu_init\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x08\x61\x63\x63uInit\x12\x44\n\x0eloop_condition\x18\x05 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\rloopCondition\x12:\n\tloop_step\x18\x06 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x08loopStep\x12\x35\n\x06result\x18\x07 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprR\x06resultB\x0b\n\texpr_kind\"\xad\x02\n\x07Literal\x12;\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00R\tnullValue\x12\x1f\n\nbool_value\x18\x02 \x01(\x08H\x00R\tboolValue\x12!\n\x0bint64_value\x18\x03 \x01(\x03H\x00R\nint64Value\x12#\n\x0cuint64_value\x18\x04 \x01(\x04H\x00R\x0buint64Value\x12#\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00R\x0b\x64oubleValue\x12#\n\x0cstring_value\x18\x06 \x01(\tH\x00R\x0bstringValue\x12!\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00R\nbytesValueB\x0f\n\rconstant_kindB\xe7\x01\n\x1b\x63om.google.api.expr.v1beta1B\tExprProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.expr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.google.api.expr.v1beta1B\tExprProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1'
  _globals['_PARSEDEXPR']._serialized_start=132
  _globals['_PARSEDEXPR']._serialized_end=304
  _globals['_EXPR']._serialized_start=307
  _globals['_EXPR']._serialized_end=1904
  _globals['_EXPR_IDENT']._serialized_start=858
  _globals['_EXPR_IDENT']._serialized_end=885
  _globals['_EXPR_SELECT']._serialized_start=887
  _globals['_EXPR_SELECT']._serialized_end=1003
  _globals['_EXPR_CALL']._serialized_start=1006
  _globals['_EXPR_CALL']._serialized_end=1146
  _globals['_EXPR_CREATELIST']._serialized_start=1148
  _globals['_EXPR_CREATELIST']._serialized_end=1219
  _globals['_EXPR_CREATESTRUCT']._serialized_start=1222
  _globals['_EXPR_CREATESTRUCT']._serialized_end=1512
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_start=1335
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_end=1512
  _globals['_EXPR_COMPREHENSION']._serialized_start=1515
  _globals['_EXPR_COMPREHENSION']._serialized_end=1891
  _globals['_LITERAL']._serialized_start=1907
  _globals['_LITERAL']._serialized_end=2208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/database.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/database.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'nodus/v1/integrations/v1/database.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\"\xcd\x04\n\x0e\x44\x61tabaseConfig\x12K\n\rdatabase_type\x18\x01 \x01(\x0e\x32&.nodus.v1.integrations.v1.DatabaseTypeR\x0c\x64\x61tabaseType\x12<\n\x1a\x63onnection_string_template\x18\x02 \x01(\tR\x18\x63onnectionStringTemplate\x12\x12\n\x04host\x18\x03 \x01(\tR\x04host\x12\x12\n\x04port\x18\x04 \x01(\x05R\x04port\x12\x1a\n\x08\x64\x61tabase\x18\x05 \x01(\tR\x08\x64\x61tabase\x12\x1a\n\x08username\x18\x06 \x01(\tR\x08username\x12\x34\n\x16password_credential_id\x18\x07 \x01(\tR\x14passwordCredentialId\x12\x17\n\x07use_ssl\x18\x08 \x01(\x08R\x06useSsl\x12k\n\x11\x63onnection_params\x18\t \x03(\x0b\x32>.nodus.v1.integrations.v1.DatabaseConfig.ConnectionParamsEntryR\x10\x63onnectionParams\x12O\n\x0bpool_config\x18\n \x01(\x0b\x32..nodus.v1.integrations.v1.ConnectionPoolConfigR\npoolConfig\x1a\x43\n\x15\x43onnectionParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xae\x02\n\x14\x43onnectionPoolConfig\x12\'\n\x0fmax_connections\x18\x01 \x01(\x05R\x0emaxConnections\x12\'\n\x0fmin_connections\x18\x02 \x01(\x05R\x0eminConnections\x12H\n\x12\x63onnection_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x63onnectionTimeout\x12<\n\x0cidle_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bidleTimeout\x12<\n\x0cmax_lifetime\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxLifetime\"\xd5\x03\n\x14VectorDatabaseConfig\x12K\n\rdatabase_type\x18\x01 \x01(\x0e\x32&.nodus.v1.integrations.v1.DatabaseTypeR\x0c\x64\x61tabaseType\x12\x31\n\x15\x61pi_key_credential_id\x18\x02 \x01(\tR\x12\x61piKeyCredentialId\x12 \n\x0b\x65nvironment\x18\x03 \x01(\tR\x0b\x65nvironment\x12\x1d\n\nindex_name\x18\x04 \x01(\tR\tindexName\x12\x1c\n\tdimension\x18\x05 \x01(\x05R\tdimension\x12\x16\n\x06metric\x18\x06 \x01(\tR\x06metric\x12k\n\x0fmetadata_config\x18\x07 \x03(\x0b\x32\x42.nodus.v1.integrations.v1.VectorDatabaseConfig.MetadataConfigEntryR\x0emetadataConfig\x1aY\n\x13MetadataConfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xdc\x01\n\x0bQueryConfig\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x37\n\nparameters\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12\x14\n\x05limit\x18\x03 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x04 \x01(\x05R\x06offset\x12\x33\n\x07timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1b\n\tread_only\x18\x06 \x01(\x08R\x08readOnly*\xa7\x02\n\x0c\x44\x61tabaseType\x12\x1d\n\x19\x44\x41TABASE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x44\x41TABASE_TYPE_POSTGRESQL\x10\x01\x12\x17\n\x13\x44\x41TABASE_TYPE_MYSQL\x10\x02\x12\x18\n\x14\x44\x41TABASE_TYPE_SQLITE\x10\x03\x12\x19\n\x15\x44\x41TABASE_TYPE_MONGODB\x10\x04\x12\x17\n\x13\x44\x41TABASE_TYPE_REDIS\x10\x05\x12\x1f\n\x1b\x44\x41TABASE_TYPE_ELASTICSEARCH\x10\x06\x12\x1a\n\x16\x44\x41TABASE_TYPE_PINECONE\x10\x07\x12\x18\n\x14\x44\x41TABASE_TYPE_QDRANT\x10\x08\x12\x1c\n\x18\x44\x41TABASE_TYPE_CLICKHOUSE\x10\tB\x85\x02\n\x1c\x63om.nodus.v1.integrations.v1B\rDatabaseProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.database_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\rDatabaseProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._loaded_options = None
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._loaded_options = None
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_options = b'8\001'
  _globals['_DATABASETYPE']._serialized_start=1724
  _globals['_DATABASETYPE']._serialized_end=2019
  _globals['_DATABASECONFIG']._serialized_start=132
  _globals['_DATABASECONFIG']._serialized_end=721
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_start=654
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_end=721
  _globals['_CONNECTIONPOOLCONFIG']._serialized_start=724
  _globals['_CONNECTIONPOOLCONFIG']._serialized_end=1026
  _globals['_VECTORDATABASECONFIG']._serialized_start=1029
  _globals['_VECTORDATABASECONFIG']._serialized_end=1498
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_start=1409
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_end=1498
  _globals['_QUERYCONFIG']._serialized_start=1501
  _globals['_QUERYCONFIG']._serialized_end=1721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/mcp/v1/server.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/mcp/v1/server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.nodus.v1.common.v1 import auth_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cnodus/v1/mcp/v1/server.proto\x12\x0fnodus.v1.mcp.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dnodus/v1/common/v1/auth.proto\"\xf7\x04\n\rMCPServerInfo\x12\x1b\n\tserver_id\x18\x01 \x01(\tR\x08serverId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08\x65ndpoint\x18\x03 \x01(\tR\x08\x65ndpoint\x12?\n\x0bserver_type\x18\x04 \x01(\x0e\x32\x1e.nodus.v1.mcp.v1.MCPServerTypeR\nserverType\x12\x38\n\x06status\x18\x05 \x01(\x0e\x32 .nodus.v1.mcp.v1.MCPServerStatusR\x06status\x12J\n\x0c\x63\x61pabilities\x18\x06 \x01(\x0b\x32&.nodus.v1.mcp.v1.MCPServerCapabilitiesR\x0c\x63\x61pabilities\x12Q\n\x11\x63onnection_config\x18\x07 \x01(\x0b\x32$.nodus.v1.mcp.v1.MCPConnectionConfigR\x10\x63onnectionConfig\x12H\n\x08metadata\x18\x08 \x03(\x0b\x32,.nodus.v1.mcp.v1.MCPServerInfo.MetadataEntryR\x08metadata\x12?\n\rregistered_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cregisteredAt\x12\x37\n\tlast_ping\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastPing\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xce\x02\n\x15MCPServerCapabilities\x12)\n\x10protocol_version\x18\x01 \x01(\tR\x0fprotocolVersion\x12-\n\x12supported_features\x18\x02 \x03(\tR\x11supportedFeatures\x12\x36\n\x17max_concurrent_requests\x18\x03 \x01(\x05R\x15maxConcurrentRequests\x12:\n\x19supported_tool_categories\x18\x04 \x03(\tR\x17supportedToolCategories\x12-\n\x12supports_streaming\x18\x05 \x01(\x08R\x11supportsStreaming\x12\x38\n\x18supports_file_operations\x18\x06 \x01(\x08R\x16supportsFileOperations\"\xcf\x04\n\x13MCPConnectionConfig\x12H\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x63onnectionTimeout\x12\x42\n\x0frequest_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0erequestTimeout\x12\x1f\n\x0bmax_retries\x18\x03 \x01(\x05R\nmaxRetries\x12>\n\rretry_backoff\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cretryBackoff\x12*\n\x11\x65nable_keep_alive\x18\x05 \x01(\x08R\x0f\x65nableKeepAlive\x12I\n\x13keep_alive_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11keepAliveInterval\x12K\n\x07headers\x18\x07 \x03(\x0b\x32\x31.nodus.v1.mcp.v1.MCPConnectionConfig.HeadersEntryR\x07headers\x12I\n\x0b\x61uth_config\x18\x08 \x01(\x0b\x32(.nodus.v1.common.v1.AuthenticationConfigR\nauthConfig\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xb7\x01\n\rMCPServerType\x12\x1f\n\x1bMCP_SERVER_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14MCP_SERVER_TYPE_HTTP\x10\x01\x12\x1d\n\x19MCP_SERVER_TYPE_WEBSOCKET\x10\x02\x12\x18\n\x14MCP_SERVER_TYPE_GRPC\x10\x03\x12\x19\n\x15MCP_SERVER_TYPE_STDIO\x10\x04\x12\x17\n\x13MCP_SERVER_TYPE_TCP\x10\x05*\xdd\x01\n\x0fMCPServerStatus\x12!\n\x1dMCP_SERVER_STATUS_UNSPECIFIED\x10\x00\x12\x1d\n\x19MCP_SERVER_STATUS_HEALTHY\x10\x01\x12\x1f\n\x1bMCP_SERVER_STATUS_UNHEALTHY\x10\x02\x12 \n\x1cMCP_SERVER_STATUS_CONNECTING\x10\x03\x12\"\n\x1eMCP_SERVER_STATUS_DISCONNECTED\x10\x04\x12!\n\x1dMCP_SERVER_STATUS_MAINTENANCE\x10\x05\x42\xc4\x01\n\x13\x63om.nodus.v1.mcp.v1B\x0bServerProtoP\x01ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\xa2\x02\x03NVM\xaa\x02\x0fNodus.V1.Mcp.V1\xca\x02\x0fNodus\\V1\\Mcp\\V1\xe2\x02\x1bNodus\\V1\\Mcp\\V1\\GPBMetadata\xea\x02\x12Nodus::V1::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.mcp.v1.server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.nodus.v1.mcp.v1B\013ServerProtoP\001ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\242\002\003NVM\252\002\017Nodus.V1.Mcp.V1\312\002\017Nodus\\V1\\Mcp\\V1\342\002\033Nodus\\V1\\Mcp\\V1\\GPBMetadata\352\002\022Nodus::V1::Mcp::V1'
  _globals['_MCPSERVERINFO_METADATAENTRY']._loaded_options = None
  _globals['_MCPSERVERINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MCPCONNECTIONCONFIG_HEADERSENTRY']._loaded_options = None
  _globals['_MCPCONNECTIONCONFIG_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_MCPSERVERTYPE']._serialized_start=1711
  _globals['_MCPSERVERTYPE']._serialized_end=1894
  _globals['_MCPSERVERSTATUS']._serialized_start=1897
  _globals['_MCPSERVERSTATUS']._serialized_end=2118
  _globals['_MCPSERVERINFO']._serialized_start=146
  _globals['_MCPSERVERINFO']._serialized_end=777
  _globals['_MCPSERVERINFO_METADATAENTRY']._serialized_start=718
  _globals['_MCPSERVERINFO_METADATAENTRY']._serialized_end=777
  _globals['_MCPSERVERCAPABILITIES']._serialized_start=780
  _globals['_MCPSERVERCAPABILITIES']._serialized_end=1114
  _globals['_MCPCONNECTIONCONFIG']._serialized_start=1117
  _globals['_MCPCONNECTIONCONFIG']._serialized_end=1708
  _globals['_MCPCONNECTIONCONFIG_HEADERSENTRY']._serialized_start=1650
  _globals['_MCPCONNECTIONCONFIG_HEADERSENTRY']._serialized_end=1708
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/decimal.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/decimal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/type/decimal.proto\x12\x0bgoogle.type\"\x1f\n\x07\x44\x65\x63imal\x12\x14\n\x05value\x18\x01 \x01(\tR\x05valueB\xab\x01\n\x0f\x63om.google.typeB\x0c\x44\x65\x63imalProtoP\x01Z:google.golang.org/genproto/googleapis/type/decimal;decimal\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.decimal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\014DecimalProtoP\001Z:google.golang.org/genproto/googleapis/type/decimal;decimal\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type'
  _globals['_DECIMAL']._serialized_start=42
  _globals['_DECIMAL']._serialized_end=73
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17polykey/v2/common.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1apolykey/v2/key_types.proto\"\xc2\x01\n\x10RequesterContext\x12\'\n\x0f\x63lient_identity\x18\x01 \x01(\tR\x0e\x63lientIdentity\x12\x37\n\x17\x63\x65rtificate_fingerprint\x18\x02 \x01(\tR\x16\x63\x65rtificateFingerprint\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12%\n\x0e\x63orrelation_id\x18\x04 \x01(\tR\rcorrelationId\"\xc2\x03\n\x10\x41\x63\x63\x65ssAttributes\x12 \n\x0b\x65nvironment\x18\x01 \x01(\tR\x0b\x65nvironment\x12!\n\x0cnetwork_zone\x18\x02 \x01(\tR\x0bnetworkZone\x12+\n\x11geographic_region\x18\x03 \x01(\tR\x10geographicRegion\x12=\n\x0crequest_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestTime\x12\x1f\n\x0btime_window\x18\x05 \x01(\tR\ntimeWindow\x12\x14\n\x05roles\x18\x06 \x03(\tR\x05roles\x12 \n\x0bpermissions\x18\x07 \x03(\tR\x0bpermissions\x12_\n\x11\x63ustom_attributes\x18\x08 \x03(\x0b\x32\x32.polykey.v2.AccessAttributes.CustomAttributesEntryR\x10\x63ustomAttributes\x1a\x43\n\x15\x43ustomAttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9c\x07\n\x0bKeyMetadata\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12.\n\x08key_type\x18\x02 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x15.polykey.v2.KeyStatusR\x06status\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x44\n\x10last_accessed_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0elastAccessedAt\x12)\n\x10\x63reator_identity\x18\t \x01(\tR\x0f\x63reatorIdentity\x12/\n\x13\x61uthorized_contexts\x18\n \x03(\tR\x12\x61uthorizedContexts\x12T\n\x0f\x61\x63\x63\x65ss_policies\x18\x0b \x03(\x0b\x32+.polykey.v2.KeyMetadata.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12\x35\n\x04tags\x18\r \x03(\x0b\x32!.polykey.v2.KeyMetadata.TagsEntryR\x04tags\x12/\n\x13\x64\x61ta_classification\x18\x0e \x01(\tR\x12\x64\x61taClassification\x12+\n\x11metadata_checksum\x18\x0f \x01(\tR\x10metadataChecksum\x12!\n\x0c\x61\x63\x63\x65ss_count\x18\x10 \x01(\x03R\x0b\x61\x63\x63\x65ssCount\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc5\x01\n\x0bKeyMaterial\x12,\n\x12\x65ncrypted_key_data\x18\x01 \x01(\x0cR\x10\x65ncryptedKeyData\x12\x31\n\x14\x65ncryption_algorithm\x18\x02 \x01(\tR\x13\x65ncryptionAlgorithm\x12\x32\n\x15key_derivation_params\x18\x03 \x01(\tR\x13keyDerivationParams\x12!\n\x0ckey_checksum\x18\x04 \x01(\tR\x0bkeyChecksum\"\xd6\x01\n\x12\x41\x63\x63\x65ssHistoryEntry\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\'\n\x0f\x63lient_identity\x18\x02 \x01(\tR\x0e\x63lientIdentity\x12\x1c\n\toperation\x18\x03 \x01(\tR\toperation\x12\x18\n\x07success\x18\x04 \x01(\x08R\x07success\x12%\n\x0e\x63orrelation_id\x18\x05 \x01(\tR\rcorrelationId\"\xe6\x02\n\x0cPolicyDetail\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x1f\n\x0bpolicy_type\x18\x02 \x01(\tR\npolicyType\x12O\n\rpolicy_params\x18\x03 \x03(\x0b\x32*.polykey.v2.PolicyDetail.PolicyParamsEntryR\x0cpolicyParams\x12\x41\n\x0e\x65\x66\x66\x65\x63tive_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\reffectiveFrom\x12\x43\n\x0f\x65\x66\x66\x65\x63tive_until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x65\x66\x66\x65\x63tiveUntil\x1a?\n\x11PolicyParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa8\x01\n\x0e\x63om.polykey.v2B\x0b\x43ommonProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\013CommonProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._loaded_options = None
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_KEYMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._loaded_options = None
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_REQUESTERCONTEXT']._serialized_start=101
  _globals['_REQUESTERCONTEXT']._serialized_end=295
  _globals['_ACCESSATTRIBUTES']._serialized_start=298
  _globals['_ACCESSATTRIBUTES']._serialized_end=748
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_start=681
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_end=748
  _globals['_KEYMETADATA']._serialized_start=751
  _globals['_KEYMETADATA']._serialized_end=1675
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_start=1553
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_end=1618
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_start=1620
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_end=1675
  _globals['_KEYMATERIAL']._serialized_start=1678
  _globals['_KEYMATERIAL']._serialized_end=1875
  _globals['_ACCESSHISTORYENTRY']._serialized_start=1878
  _globals['_ACCESSHISTORYENTRY']._serialized_end=2092
  _globals['_POLICYDETAIL']._serialized_start=2095
  _globals['_POLICYDETAIL']._serialized_end=2453
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_start=2390
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_end=2453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/execution.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.common.v1 import resources_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_resources__pb2
from spounge.nodus.v1.common.v1 import errors_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_errors__pb2
from spounge.nodus.v1.nodes.v1 import direct_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_direct__pb2
from spounge.nodus.v1.nodes.v1 import reasoning_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_reasoning__pb2
from spounge.nodus.v1.nodes.v1 import autonomous_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_autonomous__pb2
from spounge.nodus.v1.nodes.v1 import webhook_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_webhook__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/nodes/v1/execution.proto\x12\x11nodus.v1.nodes.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/common/v1/resources.proto\x1a\x1fnodus/v1/common/v1/errors.proto\x1a\x1enodus/v1/nodes/v1/direct.proto\x1a!nodus/v1/nodes/v1/reasoning.proto\x1a\"nodus/v1/nodes/v1/autonomous.proto\x1a\x1fnodus/v1/nodes/v1/webhook.proto\"\xca\x05\n\x12\x45xecuteNodeRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x39\n\tnode_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.common.v1.NodeTypeR\x08nodeType\x12\x33\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1f\n\x0bmax_retries\x18\x05 \x01(\x05R\nmaxRetries\x12J\n\rdirect_config\x18\n \x01(\x0b\x32#.nodus.v1.nodes.v1.DirectNodeConfigH\x00R\x0c\x64irectConfig\x12S\n\x10reasoning_config\x18\x0b \x01(\x0b\x32&.nodus.v1.nodes.v1.ReasoningNodeConfigH\x00R\x0freasoningConfig\x12V\n\x11\x61utonomous_config\x18\x0c \x01(\x0b\x32\'.nodus.v1.nodes.v1.AutonomousNodeConfigH\x00R\x10\x61utonomousConfig\x12M\n\x0ewebhook_config\x18\r \x01(\x0b\x32$.nodus.v1.nodes.v1.WebhookNodeConfigH\x00R\rwebhookConfig\x12Q\n\x11\x65xecution_context\x18\x14 \x01(\x0b\x32$.nodus.v1.common.v1.ExecutionContextR\x10\x65xecutionContext\x12=\n\x0crequested_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAtB\r\n\x0bnode_config\"\x92\x04\n\x13\x45xecuteNodeResponse\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12;\n\x06status\x18\x03 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\x06status\x12\x35\n\x0bresult_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\nresultData\x12@\n\x08metadata\x18\x05 \x01(\x0b\x32$.nodus.v1.nodes.v1.ExecutionMetadataR\x08metadata\x12\x38\n\x05\x65rror\x18\x06 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\x05\x65rror\x12@\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12N\n\x0eresource_usage\x18\x08 \x01(\x0b\x32\'.nodus.v1.common.v1.ResourceConsumptionR\rresourceUsage\x12=\n\x0c\x63ompleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"\xac\x05\n\x11\x45xecutionMetadata\x12I\n\x0f\x65xecution_steps\x18\x01 \x03(\x0b\x32 .nodus.v1.nodes.v1.ExecutionStepR\x0e\x65xecutionSteps\x12)\n\x10total_iterations\x18\x02 \x01(\x05R\x0ftotalIterations\x12)\n\x10tool_invocations\x18\x03 \x01(\x05R\x0ftoolInvocations\x12I\n\x13llm_processing_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11llmProcessingTime\x12I\n\x13tool_execution_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11toolExecutionTime\x12H\n\x12serialization_time\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11serializationTime\x12)\n\x10\x63onfidence_score\x18\x07 \x01(\x02R\x0f\x63onfidenceScore\x12-\n\x12termination_reason\x18\x08 \x01(\tR\x11terminationReason\x12\x1a\n\x08warnings\x18\t \x03(\tR\x08warnings\x12^\n\x0e\x63ustom_metrics\x18\n \x03(\x0b\x32\x37.nodus.v1.nodes.v1.ExecutionMetadata.CustomMetricsEntryR\rcustomMetrics\x1a@\n\x12\x43ustomMetricsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc1\x03\n\rExecutionStep\x12\x1f\n\x0bstep_number\x18\x01 \x01(\x05R\nstepNumber\x12\x38\n\tstep_type\x18\x02 \x01(\x0e\x32\x1b.nodus.v1.nodes.v1.StepTypeR\x08stepType\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x33\n\nstep_input\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\tstepInput\x12\x35\n\x0bstep_output\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyR\nstepOutput\x12>\n\rstep_duration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cstepDuration\x12\x44\n\x0bstep_status\x18\x07 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\nstepStatus\x12\x41\n\nstep_error\x18\x08 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\tstepError\"\xd0\x05\n\x18\x45xecuteNodeStreamRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x39\n\tnode_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.common.v1.NodeTypeR\x08nodeType\x12\x33\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1f\n\x0bmax_retries\x18\x05 \x01(\x05R\nmaxRetries\x12J\n\rdirect_config\x18\n \x01(\x0b\x32#.nodus.v1.nodes.v1.DirectNodeConfigH\x00R\x0c\x64irectConfig\x12S\n\x10reasoning_config\x18\x0b \x01(\x0b\x32&.nodus.v1.nodes.v1.ReasoningNodeConfigH\x00R\x0freasoningConfig\x12V\n\x11\x61utonomous_config\x18\x0c \x01(\x0b\x32\'.nodus.v1.nodes.v1.AutonomousNodeConfigH\x00R\x10\x61utonomousConfig\x12M\n\x0ewebhook_config\x18\r \x01(\x0b\x32$.nodus.v1.nodes.v1.WebhookNodeConfigH\x00R\rwebhookConfig\x12Q\n\x11\x65xecution_context\x18\x14 \x01(\x0b\x32$.nodus.v1.common.v1.ExecutionContextR\x10\x65xecutionContext\x12=\n\x0crequested_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAtB\r\n\x0bnode_config\"\x98\x04\n\x19\x45xecuteNodeStreamResponse\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12;\n\x06status\x18\x03 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\x06status\x12\x35\n\x0bresult_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\nresultData\x12@\n\x08metadata\x18\x05 \x01(\x0b\x32$.nodus.v1.nodes.v1.ExecutionMetadataR\x08metadata\x12\x38\n\x05\x65rror\x18\x06 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\x05\x65rror\x12@\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12N\n\x0eresource_usage\x18\x08 \x01(\x0b\x32\'.nodus.v1.common.v1.ResourceConsumptionR\rresourceUsage\x12=\n\x0c\x63ompleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt*\xb4\x01\n\x08StepType\x12\x19\n\x15STEP_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13STEP_TYPE_REASONING\x10\x01\x12\x1d\n\x19STEP_TYPE_TOOL_INVOCATION\x10\x02\x12\x1f\n\x1bSTEP_TYPE_RESULT_PROCESSING\x10\x03\x12\x1a\n\x16STEP_TYPE_STATE_UPDATE\x10\x04\x12\x18\n\x14STEP_TYPE_VALIDATION\x10\x05\x42\xd5\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0e\x45xecutionProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\016ExecutionProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._loaded_options = None
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_options = b'8\001'
  _globals['_STEPTYPE']._serialized_start=4037
  _globals['_STEPTYPE']._serialized_end=4217
  _globals['_EXECUTENODEREQUEST']._serialized_start=386
  _globals['_EXECUTENODEREQUEST']._serialized_end=1100
  _globals['_EXECUTENODERESPONSE']._serialized_start=1103
  _globals['_EXECUTENODERESPONSE']._serialized_end=1633
  _globals['_EXECUTIONMETADATA']._serialized_start=1636
  _globals['_EXECUTIONMETADATA']._serialized_end=2320
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_start=2256
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_end=2320
  _globals['_EXECUTIONSTEP']._serialized_start=2323
  _globals['_EXECUTIONSTEP']._serialized_end=2772
  _globals['_EXECUTENODESTREAMREQUEST']._serialized_start=2775
  _globals['_EXECUTENODESTREAMREQUEST']._serialized_end=3495
  _globals['_EXECUTENODESTREAMRESPONSE']._serialized_start=3498
  _globals['_EXECUTENODESTREAMRESPONSE']._serialized_end=4034
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/webhook.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nodus/v1/integrations/v1/webhook.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x03\n\x0fWebhookCallback\x12P\n\x07headers\x18\x01 \x03(\x0b\x32\x36.nodus.v1.integrations.v1.WebhookCallback.HeadersEntryR\x07headers\x12]\n\x0cquery_params\x18\x02 \x03(\x0b\x32:.nodus.v1.integrations.v1.WebhookCallback.QueryParamsEntryR\x0bqueryParams\x12+\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12;\n\x0breceived_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreceivedAt\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10QueryParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x84\x02\n\x1c\x63om.nodus.v1.integrations.v1B\x0cWebhookProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\014WebhookProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._loaded_options = None
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._loaded_options = None
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKCALLBACK']._serialized_start=132
  _globals['_WEBHOOKCALLBACK']._serialized_end=556
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_start=434
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_end=492
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_start=494
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_end=556
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/metrics.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/metrics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/metrics.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x03\n\x0eServiceMetrics\x12\x37\n\x18\x61verage_response_time_ms\x18\x01 \x01(\x01R\x15\x61verageResponseTimeMs\x12.\n\x13requests_per_second\x18\x02 \x01(\x03R\x11requestsPerSecond\x12,\n\x12\x65rror_rate_percent\x18\x03 \x01(\x01R\x10\x65rrorRatePercent\x12*\n\x11\x63pu_usage_percent\x18\x04 \x01(\x01R\x0f\x63puUsagePercent\x12\x30\n\x14memory_usage_percent\x18\x05 \x01(\x01R\x12memoryUsagePercent\x12*\n\x11\x61\x63tive_keys_count\x18\x06 \x01(\x03R\x0f\x61\x63tiveKeysCount\x12\x34\n\x16total_requests_handled\x18\x07 \x01(\x03R\x14totalRequestsHandled\x12=\n\x0cuptime_since\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0buptimeSince\"\x83\x02\n\x13HealthCheckResponse\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32\x18.polykey.v2.HealthStatusR\x06status\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x34\n\x07metrics\x18\x03 \x01(\x0b\x32\x1a.polykey.v2.ServiceMetricsR\x07metrics\x12\'\n\x0fservice_version\x18\x04 \x01(\tR\x0eserviceVersion\x12!\n\x0c\x62uild_commit\x18\x05 \x01(\tR\x0b\x62uildCommit*\x81\x01\n\x0cHealthStatus\x12\x1d\n\x19HEALTH_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15HEALTH_STATUS_HEALTHY\x10\x01\x12\x1a\n\x16HEALTH_STATUS_DEGRADED\x10\x02\x12\x1b\n\x17HEALTH_STATUS_UNHEALTHY\x10\x03\x42\xa9\x01\n\x0e\x63om.polykey.v2B\x0cMetricsProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.metrics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014MetricsProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_HEALTHSTATUS']._serialized_start=761
  _globals['_HEALTHSTATUS']._serialized_end=890
  _globals['_SERVICEMETRICS']._serialized_start=74
  _globals['_SERVICEMETRICS']._serialized_end=496
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=499
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=758
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/auth_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/auth_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.auth.v2 import auth_service_pb2 as auth_dot_v2_dot_auth__service__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!api/v2/auth_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1a\x61uth/v2/auth_service.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"\\\n\x1e\x41uthGatewayServiceLoginRequest\x12:\n\rlogin_request\x18\x01 \x01(\x0b\x32\x15.auth.v2.LoginRequestR\x0cloginRequest\"`\n\x1f\x41uthGatewayServiceLoginResponse\x12=\n\x0elogin_response\x18\x01 \x01(\x0b\x32\x16.auth.v2.LoginResponseR\rloginResponse\"y\n%AuthGatewayServiceRefreshTokenRequest\x12P\n\x15refresh_token_request\x18\x01 \x01(\x0b\x32\x1c.auth.v2.RefreshTokenRequestR\x13refreshTokenRequest\"}\n&AuthGatewayServiceRefreshTokenResponse\x12S\n\x16refresh_token_response\x18\x01 \x01(\x0b\x32\x1d.auth.v2.RefreshTokenResponseR\x14refreshTokenResponse\"O\n\x1f\x41uthGatewayServiceLogoutRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty\"d\n AuthGatewayServiceLogoutResponse\x12@\n\x0flogout_response\x18\x01 \x01(\x0b\x32\x17.auth.v2.LogoutResponseR\x0elogoutResponse2\x8f\x03\n\x12\x41uthGatewayService\x12s\n\x05Login\x12&.api.v2.AuthGatewayServiceLoginRequest\x1a\'.api.v2.AuthGatewayServiceLoginResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v2/auth/login:\x01*\x12\x8a\x01\n\x0cRefreshToken\x12-.api.v2.AuthGatewayServiceRefreshTokenRequest\x1a..api.v2.AuthGatewayServiceRefreshTokenResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/auth/refresh:\x01*\x12w\n\x06Logout\x12\'.api.v2.AuthGatewayServiceLogoutRequest\x1a(.api.v2.AuthGatewayServiceLogoutResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v2/auth/logout:\x01*B\x98\x01\n\ncom.api.v2B\x17\x41uthGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.auth_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\027AuthGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Login']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Login']._serialized_options = b'\202\323\344\223\002\023\"\016/v2/auth/login:\001*'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['RefreshToken']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['RefreshToken']._serialized_options = b'\202\323\344\223\002\025\"\020/v2/auth/refresh:\001*'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Logout']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Logout']._serialized_options = b'\202\323\344\223\002\024\"\017/v2/auth/logout:\001*'
  _globals['_AUTHGATEWAYSERVICELOGINREQUEST']._serialized_start=132
  _globals['_AUTHGATEWAYSERVICELOGINREQUEST']._serialized_end=224
  _globals['_AUTHGATEWAYSERVICELOGINRESPONSE']._serialized_start=226
  _globals['_AUTHGATEWAYSERVICELOGINRESPONSE']._serialized_end=322
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST']._serialized_start=324
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST']._serialized_end=445
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE']._serialized_start=447
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE']._serialized_end=572
  _globals['_AUTHGATEWAYSERVICELOGOUTREQUEST']._serialized_start=574
  _globals['_AUTHGATEWAYSERVICELOGOUTREQUEST']._serialized_end=653
  _globals['_AUTHGATEWAYSERVICELOGOUTRESPONSE']._serialized_start=655
  _globals['_AUTHGATEWAYSERVICELOGOUTRESPONSE']._serialized_end=755
  _globals['_AUTHGATEWAYSERVICE']._serialized_start=758
  _globals['_AUTHGATEWAYSERVICE']._serialized_end=1157
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import common
from . import integrations
from . import mcp
from . import nodes
from . import service

__all__ = ["common", "integrations", "mcp", "nodes", "service"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/workflow_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/workflow_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from spounge.workflow.v2 import workflow_pb2 as workflow_dot_v2_dot_workflow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"workflow/v2/workflow_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a google/protobuf/field_mask.proto\x1a\x1aworkflow/v2/workflow.proto\"\x93\x01\n\x15\x43reateWorkflowRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x03 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description\"Q\n\x16\x43reateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"`\n\x12GetWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12\x1d\n\x07version\x18\x02 \x01(\x05H\x00R\x07version\x88\x01\x01\x42\n\n\x08_version\"N\n\x13GetWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"\xf1\x01\n\x15UpdateWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x05 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description\"Q\n\x16UpdateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"8\n\x15\x44\x65leteWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\"C\n\x16\x44\x65leteWorkflowResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\"S\n\x14ListWorkflowsRequest\x12;\n\npagination\x18\x01 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination\"\x8f\x01\n\x15ListWorkflowsResponse\x12\x39\n\tworkflows\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\tworkflows\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination\">\n\x1bListWorkflowVersionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\"W\n\x1cListWorkflowVersionsResponse\x12\x37\n\x08versions\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08versions2\xc5\x04\n\x0fWorkflowService\x12[\n\x0e\x43reateWorkflow\x12\".workflow.v2.CreateWorkflowRequest\x1a#.workflow.v2.CreateWorkflowResponse\"\x00\x12R\n\x0bGetWorkflow\x12\x1f.workflow.v2.GetWorkflowRequest\x1a .workflow.v2.GetWorkflowResponse\"\x00\x12[\n\x0eUpdateWorkflow\x12\".workflow.v2.UpdateWorkflowRequest\x1a#.workflow.v2.UpdateWorkflowResponse\"\x00\x12[\n\x0e\x44\x65leteWorkflow\x12\".workflow.v2.DeleteWorkflowRequest\x1a#.workflow.v2.DeleteWorkflowResponse\"\x00\x12X\n\rListWorkflows\x12!.workflow.v2.ListWorkflowsRequest\x1a\".workflow.v2.ListWorkflowsResponse\"\x00\x12m\n\x14ListWorkflowVersions\x12(.workflow.v2.ListWorkflowVersionsRequest\x1a).workflow.v2.ListWorkflowVersionsResponse\"\x00\x42\xb8\x01\n\x0f\x63om.workflow.v2B\x14WorkflowServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.workflow_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\024WorkflowServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_CREATEWORKFLOWREQUEST']._serialized_start=138
  _globals['_CREATEWORKFLOWREQUEST']._serialized_end=285
  _globals['_CREATEWORKFLOWRESPONSE']._serialized_start=287
  _globals['_CREATEWORKFLOWRESPONSE']._serialized_end=368
  _globals['_GETWORKFLOWREQUEST']._serialized_start=370
  _globals['_GETWORKFLOWREQUEST']._serialized_end=466
  _globals['_GETWORKFLOWRESPONSE']._serialized_start=468
  _globals['_GETWORKFLOWRESPONSE']._serialized_end=546
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_start=549
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_end=790
  _globals['_UPDATEWORKFLOWRESPONSE']._serialized_start=792
  _globals['_UPDATEWORKFLOWRESPONSE']._serialized_end=873
  _globals['_DELETEWORKFLOWREQUEST']._serialized_start=875
  _globals['_DELETEWORKFLOWREQUEST']._serialized_end=931
  _globals['_DELETEWORKFLOWRESPONSE']._serialized_start=933
  _globals['_DELETEWORKFLOWRESPONSE']._serialized_end=1000
  _globals['_LISTWORKFLOWSREQUEST']._serialized_start=1002
  _globals['_LISTWORKFLOWSREQUEST']._serialized_end=1085
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_start=1088
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_end=1231
  _globals['_LISTWORKFLOWVERSIONSREQUEST']._serialized_start=1233
  _globals['_LISTWORKFLOWVERSIONSREQUEST']._serialized_end=1295
  _globals['_LISTWORKFLOWVERSIONSRESPONSE']._serialized_start=1297
  _globals['_LISTWORKFLOWVERSIONSRESPONSE']._serialized_end=1384
  _globals['_WORKFLOWSERVICE']._serialized_start=1387
  _globals['_WORKFLOWSERVICE']._serialized_end=1968
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: llm/v2/llm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'llm/v2/llm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10llm/v2/llm.proto\x12\x06llm.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\"n\n\x07Message\x12\'\n\x04role\x18\x01 \x01(\x0e\x32\x13.llm.v2.MessageRoleR\x04role\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12\x17\n\x04name\x18\x03 \x01(\tH\x00R\x04name\x88\x01\x01\x42\x07\n\x05_name\"u\n\x04Tool\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\"L\n\x08ToolCall\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1c\n\targuments\x18\x03 \x01(\tR\targuments\"\xef\x01\n\x10GenerationParams\x12%\n\x0btemperature\x18\x01 \x01(\x02H\x00R\x0btemperature\x88\x01\x01\x12\x18\n\x05top_p\x18\x02 \x01(\x02H\x01R\x04topP\x88\x01\x01\x12\"\n\nmax_tokens\x18\x03 \x01(\x05H\x02R\tmaxTokens\x88\x01\x01\x12%\n\x0estop_sequences\x18\x04 \x03(\tR\rstopSequences\x12\x1b\n\x06stream\x18\x05 \x01(\x08H\x03R\x06stream\x88\x01\x01\x42\x0e\n\x0c_temperatureB\x08\n\x06_top_pB\r\n\x0b_max_tokensB\t\n\x07_stream\"\x81\x01\n\nTokenUsage\x12#\n\rprompt_tokens\x18\x01 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\"\x9d\x02\n\x13GenerateTextRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12+\n\x08messages\x18\x03 \x03(\x0b\x32\x0f.llm.v2.MessageR\x08messages\x12\x35\n\x06params\x18\x04 \x01(\x0b\x32\x18.llm.v2.GenerationParamsH\x00R\x06params\x88\x01\x01\x12\"\n\x05tools\x18\x05 \x03(\x0b\x32\x0c.llm.v2.ToolR\x05tools\x12/\n\x08metadata\x18\x06 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadataB\t\n\x07_params\"\x8c\x02\n\x14GenerateTextResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12:\n\x10response_message\x18\x02 \x01(\x0b\x32\x0f.llm.v2.MessageR\x0fresponseMessage\x12/\n\ntool_calls\x18\x03 \x03(\x0b\x32\x10.llm.v2.ToolCallR\ttoolCalls\x12-\n\x05usage\x18\x04 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12#\n\rfinish_reason\x18\x05 \x01(\tR\x0c\x66inishReasonB\x08\n\x06_usage\"R\n\x19GenerateTextStreamRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32\x1b.llm.v2.GenerateTextRequestR\x07request\"\xed\x01\n\x1aGenerateTextStreamResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x14\n\x05\x64\x65lta\x18\x02 \x01(\tR\x05\x64\x65lta\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12(\n\rfinish_reason\x18\x04 \x01(\tH\x01R\x0c\x66inishReason\x88\x01\x01\x12\x19\n\x08is_final\x18\x05 \x01(\x08R\x07isFinalB\x08\n\x06_usageB\x10\n\x0e_finish_reason\"\xa5\x01\n\x18GenerateEmbeddingRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x14\n\x05texts\x18\x03 \x03(\tR\x05texts\x12/\n\x08metadata\x18\x04 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadata\"A\n\tEmbedding\x12\x16\n\x06values\x18\x01 \x03(\x02R\x06values\x12\x1c\n\tdimension\x18\x02 \x01(\x05R\tdimension\"\xb2\x01\n\x19GenerateEmbeddingResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x31\n\nembeddings\x18\x02 \x03(\x0b\x32\x11.llm.v2.EmbeddingR\nembeddings\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x42\x08\n\x06_usage*\xab\x01\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\x13\n\x0fPROVIDER_OPENAI\x10\x01\x12\x16\n\x12PROVIDER_ANTHROPIC\x10\x02\x12\x13\n\x0fPROVIDER_GOOGLE\x10\x03\x12\x19\n\x15PROVIDER_AZURE_OPENAI\x10\x04\x12\x13\n\x0fPROVIDER_COHERE\x10\x05\x12\x13\n\x0fPROVIDER_OLLAMA\x10\x06*\x8e\x01\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x03\x12\x15\n\x11MESSAGE_ROLE_TOOL\x10\x04\x32\x9e\x02\n\x12LLMProviderService\x12K\n\x0cGenerateText\x12\x1b.llm.v2.GenerateTextRequest\x1a\x1c.llm.v2.GenerateTextResponse\"\x00\x12_\n\x12GenerateTextStream\x12!.llm.v2.GenerateTextStreamRequest\x1a\".llm.v2.GenerateTextStreamResponse\"\x00\x30\x01\x12Z\n\x11GenerateEmbedding\x12 .llm.v2.GenerateEmbeddingRequest\x1a!.llm.v2.GenerateEmbeddingResponse\"\x00\x42\x89\x01\n\ncom.llm.v2B\x08LlmProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\xa2\x02\x03LXX\xaa\x02\x06Llm.V2\xca\x02\x06Llm\\V2\xe2\x02\x12Llm\\V2\\GPBMetadata\xea\x02\x07Llm::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'llm.v2.llm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.llm.v2B\010LlmProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\242\002\003LXX\252\002\006Llm.V2\312\002\006Llm\\V2\342\002\022Llm\\V2\\GPBMetadata\352\002\007Llm::V2'
  _globals['_PROVIDER']._serialized_start=2065
  _globals['_PROVIDER']._serialized_end=2236
  _globals['_MESSAGEROLE']._serialized_start=2239
  _globals['_MESSAGEROLE']._serialized_end=2381
  _globals['_MESSAGE']._serialized_start=82
  _globals['_MESSAGE']._serialized_end=192
  _globals['_TOOL']._serialized_start=194
  _globals['_TOOL']._serialized_end=311
  _globals['_TOOLCALL']._serialized_start=313
  _globals['_TOOLCALL']._serialized_end=389
  _globals['_GENERATIONPARAMS']._serialized_start=392
  _globals['_GENERATIONPARAMS']._serialized_end=631
  _globals['_TOKENUSAGE']._serialized_start=634
  _globals['_TOKENUSAGE']._serialized_end=763
  _globals['_GENERATETEXTREQUEST']._serialized_start=766
  _globals['_GENERATETEXTREQUEST']._serialized_end=1051
  _globals['_GENERATETEXTRESPONSE']._serialized_start=1054
  _globals['_GENERATETEXTRESPONSE']._serialized_end=1322
  _globals['_GENERATETEXTSTREAMREQUEST']._serialized_start=1324
  _globals['_GENERATETEXTSTREAMREQUEST']._serialized_end=1406
  _globals['_GENERATETEXTSTREAMRESPONSE']._serialized_start=1409
  _globals['_GENERATETEXTSTREAMRESPONSE']._serialized_end=1646
  _globals['_GENERATEEMBEDDINGREQUEST']._serialized_start=1649
  _globals['_GENERATEEMBEDDINGREQUEST']._serialized_end=1814
  _globals['_EMBEDDING']._serialized_start=1816
  _globals['_EMBEDDING']._serialized_end=1881
  _globals['_GENERATEEMBEDDINGRESPONSE']._serialized_start=1884
  _globals['_GENERATEEMBEDDINGRESPONSE']._serialized_end=2062
  _globals['_LLMPROVIDERSERVICE']._serialized_start=2384
  _globals['_LLMPROVIDERSERVICE']._serialized_end=2670
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import auth_gateway_service_pb2, auth_gateway_service_pb2_grpc, dashboard_service_pb2, dashboard_service_pb2_grpc, user_gateway_service_pb2, user_gateway_service_pb2_grpc, workflow_gateway_service_pb2, workflow_gateway_service_pb2_grpc

__all__ = ["auth_gateway_service_pb2", "auth_gateway_service_pb2_grpc", "dashboard_service_pb2", "dashboard_service_pb2_grpc", "user_gateway_service_pb2", "user_gateway_service_pb2_grpc", "workflow_gateway_service_pb2", "workflow_gateway_service_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/user_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/user_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.user.v2 import user_service_pb2 as user_dot_v2_dot_user__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!api/v2/user_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1auser/v2/user_service.proto\"W\n\'UserGatewayServiceGetUserProfileRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty\"\x86\x01\n(UserGatewayServiceGetUserProfileResponse\x12Z\n\x19get_user_profile_response\x18\x01 \x01(\x0b\x32\x1f.user.v2.GetUserProfileResponseR\x16getUserProfileResponse\"\x8e\x01\n*UserGatewayServiceUpdateUserProfileRequest\x12`\n\x1bupdate_user_profile_request\x18\x01 \x01(\x0b\x32!.user.v2.UpdateUserProfileRequestR\x18updateUserProfileRequest\"\x92\x01\n+UserGatewayServiceUpdateUserProfileResponse\x12\x63\n\x1cupdate_user_profile_response\x18\x01 \x01(\x0b\x32\".user.v2.UpdateUserProfileResponseR\x19updateUserProfileResponse2\xc0\x02\n\x12UserGatewayService\x12\x8d\x01\n\x0eGetUserProfile\x12/.api.v2.UserGatewayServiceGetUserProfileRequest\x1a\x30.api.v2.UserGatewayServiceGetUserProfileResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v2/user/profile\x12\x99\x01\n\x11UpdateUserProfile\x12\x32.api.v2.UserGatewayServiceUpdateUserProfileRequest\x1a\x33.api.v2.UserGatewayServiceUpdateUserProfileResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x32\x10/v2/user/profile:\x01*B\x98\x01\n\ncom.api.v2B\x17UserGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.user_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\027UserGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_USERGATEWAYSERVICE'].methods_by_name['GetUserProfile']._loaded_options = None
  _globals['_USERGATEWAYSERVICE'].methods_by_name['GetUserProfile']._serialized_options = b'\202\323\344\223\002\022\022\020/v2/user/profile'
  _globals['_USERGATEWAYSERVICE'].methods_by_name['UpdateUserProfile']._loaded_options = None
  _globals['_USERGATEWAYSERVICE'].methods_by_name['UpdateUserProfile']._serialized_options = b'\202\323\344\223\002\0252\020/v2/user/profile:\001*'
  _globals['_USERGATEWAYSERVICEGETUSERPROFILEREQUEST']._serialized_start=132
  _globals['_USERGATEWAYSERVICEGETUSERPROFILEREQUEST']._serialized_end=219
  _globals['_USERGATEWAYSERVICEGETUSERPROFILERESPONSE']._serialized_start=222
  _globals['_USERGATEWAYSERVICEGETUSERPROFILERESPONSE']._serialized_end=356
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST']._serialized_start=359
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST']._serialized_end=501
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE']._serialized_start=504
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE']._serialized_end=650
  _globals['_USERGATEWAYSERVICE']._serialized_start=653
  _globals['_USERGATEWAYSERVICE']._serialized_end=973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/autonomous.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/autonomous.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.integrations.v1 import llm_pb2 as nodus_dot_v1_dot_integrations_dot_v1_dot_llm__pb2
from spounge.nodus.v1.mcp.v1 import tool_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_tool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/nodes/v1/autonomous.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/integrations/v1/llm.proto\x1a\x1anodus/v1/mcp/v1/tool.proto\"\xef\x06\n\x14\x41utonomousNodeConfig\x12I\n\nllm_config\x18\x01 \x01(\x0b\x32*.nodus.v1.integrations.v1.LLMConfigurationR\tllmConfig\x12;\n\nagent_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.nodes.v1.AgentTypeR\tagentType\x12\x1c\n\tobjective\x18\x04 \x01(\tR\tobjective\x12%\n\x0esystem_context\x18\x05 \x01(\tR\rsystemContext\x12J\n\x10initial_messages\x18\x06 \x03(\x0b\x32\x1f.nodus.v1.common.v1.ChatMessageR\x0finitialMessages\x12\x39\n\ntool_scope\x18\x07 \x01(\x0b\x32\x1a.nodus.v1.mcp.v1.ToolScopeR\ttoolScope\x12M\n\rtool_strategy\x18\x08 \x01(\x0e\x32(.nodus.v1.nodes.v1.ToolSelectionStrategyR\x0ctoolStrategy\x12%\n\x0emax_iterations\x18\t \x01(\x05R\rmaxIterations\x12G\n\x12max_execution_time\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x10maxExecutionTime\x12\x31\n\x14\x63onfidence_threshold\x18\x0b \x01(\x02R\x13\x63onfidenceThreshold\x12#\n\rpersist_state\x18\x0c \x01(\x08R\x0cpersistState\x12\x1b\n\tstate_key\x18\r \x01(\tR\x08stateKey\x12\x36\n\tstate_ttl\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x08stateTtl\x12)\n\x10\x65nable_streaming\x18\x0f \x01(\x08R\x0f\x65nableStreaming\x12,\n\x12stream_interval_ms\x18\x10 \x01(\x05R\x10streamIntervalMs\x12>\n\x07options\x18\x11 \x01(\x0b\x32$.nodus.v1.nodes.v1.AutonomousOptionsR\x07options\"\xcf\x03\n\x11\x41utonomousOptions\x12\x34\n\x16\x65nable_self_reflection\x18\x01 \x01(\x08R\x14\x65nableSelfReflection\x12/\n\x13reflection_interval\x18\x02 \x01(\x05R\x12reflectionInterval\x12>\n\x1b\x65nable_memory_consolidation\x18\x03 \x01(\x08R\x19\x65nableMemoryConsolidation\x12:\n\x19\x65nable_goal_decomposition\x18\x04 \x01(\x08R\x17\x65nableGoalDecomposition\x12)\n\x10\x65xploration_rate\x18\x05 \x01(\x02R\x0f\x65xplorationRate\x12g\n\x11\x63ustom_parameters\x18\x06 \x03(\x0b\x32:.nodus.v1.nodes.v1.AutonomousOptions.CustomParametersEntryR\x10\x63ustomParameters\x1a\x43\n\x15\x43ustomParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xaf\x01\n\tAgentType\x12\x1a\n\x16\x41GENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41GENT_TYPE_REACT\x10\x01\x12\x1f\n\x1b\x41GENT_TYPE_CHAIN_OF_THOUGHT\x10\x02\x12\x1b\n\x17\x41GENT_TYPE_TOOL_CALLING\x10\x03\x12\x17\n\x13\x41GENT_TYPE_PLANNING\x10\x04\x12\x19\n\x15\x41GENT_TYPE_REFLECTION\x10\x05*\xdb\x01\n\x15ToolSelectionStrategy\x12\'\n#TOOL_SELECTION_STRATEGY_UNSPECIFIED\x10\x00\x12%\n!TOOL_SELECTION_STRATEGY_AUTOMATIC\x10\x01\x12$\n TOOL_SELECTION_STRATEGY_EXPLICIT\x10\x02\x12\'\n#TOOL_SELECTION_STRATEGY_INTERACTIVE\x10\x03\x12#\n\x1fTOOL_SELECTION_STRATEGY_LEARNED\x10\x04\x42\xd6\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0f\x41utonomousProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.autonomous_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\017AutonomousProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._loaded_options = None
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_AGENTTYPE']._serialized_start=1534
  _globals['_AGENTTYPE']._serialized_end=1709
  _globals['_TOOLSELECTIONSTRATEGY']._serialized_start=1712
  _globals['_TOOLSELECTIONSTRATEGY']._serialized_end=1931
  _globals['_AUTONOMOUSNODECONFIG']._serialized_start=186
  _globals['_AUTONOMOUSNODECONFIG']._serialized_end=1065
  _globals['_AUTONOMOUSOPTIONS']._serialized_start=1068
  _globals['_AUTONOMOUSOPTIONS']._serialized_end=1531
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_start=1464
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_end=1531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/reasoning.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/reasoning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.integrations.v1 import llm_pb2 as nodus_dot_v1_dot_integrations_dot_v1_dot_llm__pb2
from spounge.nodus.v1.mcp.v1 import tool_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_tool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/nodes/v1/reasoning.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/integrations/v1/llm.proto\x1a\x1anodus/v1/mcp/v1/tool.proto\"\x88\x05\n\x13ReasoningNodeConfig\x12I\n\nllm_config\x18\x01 \x01(\x0b\x32*.nodus.v1.integrations.v1.LLMConfigurationR\tllmConfig\x12R\n\x10model_parameters\x18\x03 \x01(\x0b\x32\'.nodus.v1.integrations.v1.LLMParametersR\x0fmodelParameters\x12#\n\rsystem_prompt\x18\x04 \x01(\tR\x0csystemPrompt\x12\x1f\n\x0buser_prompt\x18\x05 \x01(\tR\nuserPrompt\x12R\n\x14\x63onversation_history\x18\x06 \x03(\x0b\x32\x1f.nodus.v1.common.v1.ChatMessageR\x13\x63onversationHistory\x12\x39\n\ntool_scope\x18\x07 \x01(\x0b\x32\x1a.nodus.v1.mcp.v1.ToolScopeR\ttoolScope\x12#\n\rallowed_tools\x18\x08 \x03(\tR\x0c\x61llowedTools\x12\'\n\x0f\x66orbidden_tools\x18\t \x03(\tR\x0e\x66orbiddenTools\x12\x46\n\x11reasoning_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationR\x10reasoningTimeout\x12(\n\x10require_tool_use\x18\x0c \x01(\x08R\x0erequireToolUse\x12=\n\x07options\x18\r \x01(\x0b\x32#.nodus.v1.nodes.v1.ReasoningOptionsR\x07options\"\xda\x02\n\x10ReasoningOptions\x12\x35\n\x17\x65nable_chain_of_thought\x18\x01 \x01(\x08R\x14\x65nableChainOfThought\x12\x36\n\x17include_reasoning_trace\x18\x02 \x01(\x08R\x15includeReasoningTrace\x12\x31\n\x14temperature_override\x18\x03 \x01(\x02R\x13temperatureOverride\x12\x32\n\x15validate_tool_outputs\x18\x04 \x01(\x08R\x13validateToolOutputs\x12:\n\x19output_format_instruction\x18\x05 \x01(\tR\x17outputFormatInstruction\x12\x34\n\x16required_output_fields\x18\x06 \x03(\tR\x14requiredOutputFieldsB\xd5\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0eReasoningProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.reasoning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\016ReasoningProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_REASONINGNODECONFIG']._serialized_start=185
  _globals['_REASONINGNODECONFIG']._serialized_end=833
  _globals['_REASONINGOPTIONS']._serialized_start=836
  _globals['_REASONINGOPTIONS']._serialized_end=1182
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.user.v2 import user_service_pb2 as user_dot_v2_dot_user__service__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
                '/user.v2.UserService/GetUserProfile',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
                _registered_method=True)
        self.UpdateUserProfile = channel.unary_unary(
                '/user.v2.UserService/UpdateUserProfile',
                request_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
                _registered_method=True)
        self.AddManagedSecret = channel.unary_unary(
                '/user.v2.UserService/AddManagedSecret',
                request_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
                _registered_method=True)
        self.ListManagedSecrets = channel.unary_unary(
                '/user.v2.UserService/ListManagedSecrets',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
                _registered_method=True)
        self.GetManagedSecret = channel.unary_unary(
                '/user.v2.UserService/GetManagedSecret',
                request_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
                _registered_method=True)
        self.DeleteManagedSecret = channel.unary_unary(
                '/user.v2.UserService/DeleteManagedSecret',
                request_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
                response_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
                _registered_method=True)


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListManagedSecrets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProfile,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.SerializeToString,
            ),
            'UpdateUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserProfile,
                    request_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.SerializeToString,
            ),
            'AddManagedSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.AddManagedSecret,
                    request_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.SerializeToString,
            ),
            'ListManagedSecrets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListManagedSecrets,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.SerializeToString,
            ),
            'GetManagedSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetManagedSecret,
                    request_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.SerializeToString,
            ),
            'DeleteManagedSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteManagedSecret,
                    request_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.FromString,
                    response_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'user.v2.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('user.v2.UserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/GetUserProfile',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/UpdateUserProfile',
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddManagedSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/AddManagedSecret',
            user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListManagedSecrets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/ListManagedSecrets',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetManagedSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/GetManagedSecret',
            user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteManagedSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/user.v2.UserService/DeleteManagedSecret',
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/rpc/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/rpc/status.proto\x12\ngoogle.rpc\x1a\x19google/protobuf/any.proto\"f\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12.\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32\x14.google.protobuf.AnyR\x07\x64\x65tailsB\xa2\x01\n\x0e\x63om.google.rpcB\x0bStatusProtoP\x01Z7google.golang.org/genproto/googleapis/rpc/status;status\xf8\x01\x01\xa2\x02\x03GRX\xaa\x02\nGoogle.Rpc\xca\x02\nGoogle\\Rpc\xe2\x02\x16Google\\Rpc\\GPBMetadata\xea\x02\x0bGoogle::Rpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.rpcB\013StatusProtoP\001Z7google.golang.org/genproto/googleapis/rpc/status;status\370\001\001\242\002\003GRX\252\002\nGoogle.Rpc\312\002\nGoogle\\Rpc\342\002\026Google\\Rpc\\GPBMetadata\352\002\013Google::Rpc'
  _globals['_STATUS']._serialized_start=66
  _globals['_STATUS']._serialized_end=168
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enodus/v1/common/v1/types.proto\x12\x12nodus.v1.common.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x02\n\x10\x45xecutionContext\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\x12N\n\x08metadata\x18\x04 \x03(\x0b\x32\x32.nodus.v1.common.v1.ExecutionContext.MetadataEntryR\x08metadata\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9e\x02\n\x0b\x43hatMessage\x12\x33\n\x04role\x18\x01 \x01(\x0e\x32\x1f.nodus.v1.common.v1.MessageRoleR\x04role\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32-.nodus.v1.common.v1.ChatMessage.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x85\x01\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10NODE_TYPE_DIRECT\x10\x01\x12\x17\n\x13NODE_TYPE_REASONING\x10\x02\x12\x18\n\x14NODE_TYPE_AUTONOMOUS\x10\x03\x12\x15\n\x11NODE_TYPE_WEBHOOK\x10\x04*\xea\x01\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XECUTION_STATUS_PENDING\x10\x01\x12\x1c\n\x18\x45XECUTION_STATUS_RUNNING\x10\x02\x12\x1e\n\x1a\x45XECUTION_STATUS_COMPLETED\x10\x03\x12\x1b\n\x17\x45XECUTION_STATUS_FAILED\x10\x04\x12\x1c\n\x18\x45XECUTION_STATUS_TIMEOUT\x10\x05\x12\x1e\n\x1a\x45XECUTION_STATUS_CANCELLED\x10\x06*z\n\x0cResultFormat\x12\x1d\n\x19RESULT_FORMAT_UNSPECIFIED\x10\x00\x12\x15\n\x11RESULT_FORMAT_RAW\x10\x01\x12\x16\n\x12RESULT_FORMAT_JSON\x10\x02\x12\x1c\n\x18RESULT_FORMAT_STRUCTURED\x10\x03*\x8e\x01\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x03\x12\x15\n\x11MESSAGE_ROLE_TOOL\x10\x04\x42\xd8\x01\n\x16\x63om.nodus.v1.common.v1B\nTypesProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\nTypesProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._loaded_options = None
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CHATMESSAGE_METADATAENTRY']._loaded_options = None
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NODETYPE']._serialized_start=691
  _globals['_NODETYPE']._serialized_end=824
  _globals['_EXECUTIONSTATUS']._serialized_start=827
  _globals['_EXECUTIONSTATUS']._serialized_end=1061
  _globals['_RESULTFORMAT']._serialized_start=1063
  _globals['_RESULTFORMAT']._serialized_end=1185
  _globals['_MESSAGEROLE']._serialized_start=1188
  _globals['_MESSAGEROLE']._serialized_end=1330
  _globals['_EXECUTIONCONTEXT']._serialized_start=88
  _globals['_EXECUTIONCONTEXT']._serialized_end=399
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_start=340
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_end=399
  _globals['_CHATMESSAGE']._serialized_start=402
  _globals['_CHATMESSAGE']._serialized_end=688
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_start=340
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_end=399
# @@protoc_insertion_point(module_scope)
